summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorUlf Magnusson <ulfalizer@gmail.com>2015-06-10 21:19:11 +0200
committerUlf Magnusson <ulfalizer@gmail.com>2015-06-10 21:19:11 +0200
commitd6d4d5adb75aa8eff9fcf55fbb5d749d5f461774 (patch)
tree8bb26550bb44dd7d671e98a324a1efe115cb0c68
parent0c84684cd8517c76ce0768eed1e36e96a8294281 (diff)
s/if's/ifs/
-rw-r--r--kconfiglib.py48
-rw-r--r--testsuite.py18
2 files changed, 33 insertions, 33 deletions
diff --git a/testsuite.py b/testsuite.py
index 84f552e..b1cd24f 100644
--- a/testsuite.py
+++ b/testsuite.py
@@ -494,7 +494,7 @@ def run_selftests():
(no selects)
Reverse (select-related) dependencies:
(no reverse dependencies)
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
(no additional dependencies)
Locations: Kconfiglib/tests/Ktext:1""")
@@ -523,7 +523,7 @@ def run_selftests():
SELECTED_2 if !(DUMMY || BASIC) (value: "y")
Reverse (select-related) dependencies:
SELECTING_1 && BASIC || SELECTING_2 && !BASIC (value: "n")
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
!BASIC && !BASIC (value: "y")
Locations: Kconfiglib/tests/Ktext:6 Kconfiglib/tests/Ktext:13""")
@@ -549,7 +549,7 @@ def run_selftests():
(no selects)
Reverse (select-related) dependencies:
(no reverse dependencies)
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
(no additional dependencies)
Locations: Kconfiglib/tests/Ktext:29""")
@@ -570,7 +570,7 @@ def run_selftests():
(no default values)
Choice symbols:
CHOICE_ITEM_1 CHOICE_ITEM_2 CHOICE_ITEM_3
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
(no additional dependencies)
Locations: Kconfiglib/tests/Ktext:35""")
@@ -591,7 +591,7 @@ def run_selftests():
(no default values)
Choice symbols:
CHOICE_ITEM_1 CHOICE_ITEM_2 CHOICE_ITEM_3
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
(no additional dependencies)
Locations: Kconfiglib/tests/Ktext:35""")
@@ -602,7 +602,7 @@ def run_selftests():
Title : simple menu
'depends on' dependencies : (no dependencies)
'visible if' dependencies : (no dependencies)
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
(no additional dependencies)
Location: Kconfiglib/tests/Ktext:47""")
@@ -611,7 +611,7 @@ def run_selftests():
Title : advanced menu
'depends on' dependencies : !BASIC (value: "y")
'visible if' dependencies : !DUMMY (value: "y")
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
!DUMMY (value: "y")
Location: Kconfiglib/tests/Ktext:51""")
@@ -621,7 +621,7 @@ def run_selftests():
Comment
Text: simple comment
Dependencies: (no dependencies)
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
(no additional dependencies)
Location: Kconfiglib/tests/Ktext:57""")
@@ -629,7 +629,7 @@ def run_selftests():
Comment
Text: advanced comment
Dependencies: !BASIC (value: "y")
- Additional dependencies from enclosing menus and if's:
+ Additional dependencies from enclosing menus and ifs:
!DUMMY (value: "y")
Location: Kconfiglib/tests/Ktext:60""")
diff --git a/kconfiglib.py b/kconfiglib.py
index b860ca0..50c3e27 100644
--- a/kconfiglib.py
+++ b/kconfiglib.py
@@ -895,12 +895,12 @@ class Config(object):
menu, or choice statement. Returns a list with the Items in the block.
end_marker -- The token that ends the block, e.g. T_ENDIF ("endif") for
- if's. None for files.
+ ifs. None for files.
parent -- The enclosing menu, choice or if, or None if we're at the top
level.
deps -- Dependencies from enclosing menus, choices and if's.
visible_if_deps (default: None) -- 'visible if' dependencies from
enclosing menus.
@@ -1309,7 +1309,7 @@ class Config(object):
self.end_line_tokens = tokens
break
# Propagate dependencies from enclosing menus and if's.
# For menus and comments..
if isinstance(stmt, (Menu, Comment)):
@@ -1359,15 +1359,15 @@ class Config(object):
if isinstance(stmt, Symbol):
stmt.orig_selects.extend(new_selects)
# Save dependencies from enclosing menus and if's
stmt.deps_from_containing = deps
# The set of symbols referenced directly by the symbol/choice plus
# all symbols referenced by enclosing menus and if's.
stmt.all_referenced_syms = \
stmt.referenced_syms | _get_expr_syms(deps)
# Propagate dependencies from enclosing menus and if's
stmt.def_exprs.extend([(val_expr, _make_and(cond_expr, deps))
for val_expr, cond_expr in new_def_exprs])
@@ -1615,7 +1615,7 @@ class Config(object):
locations_str = " ".join(["{0}:{1}".format(filename, linenr) for
(filename, linenr) in sc.def_locations])
- # Build additional-dependencies-from-menus-and-if's string
+ # Build additional-dependencies-from-menus-and-ifs string
additional_deps_str = " " + self._expr_val_str(sc.deps_from_containing,
"(no additional dependencies)")
@@ -1684,7 +1684,7 @@ class Config(object):
"Reverse (select-related) dependencies:",
" (no reverse dependencies)" if sc.rev_dep == "n"
else " " + self._expr_val_str(sc.rev_dep),
- "Additional dependencies from enclosing menus and if's:",
+ "Additional dependencies from enclosing menus and ifs:",
additional_deps_str,
"Locations: " + locations_str)
@@ -1730,7 +1730,7 @@ class Config(object):
defaults_str,
"Choice symbols:",
" " + syms_string,
- "Additional dependencies from enclosing menus and if's:",
+ "Additional dependencies from enclosing menus and ifs:",
additional_deps_str,
"Locations: " + locations_str)
@@ -2182,7 +2182,7 @@ class Symbol(Item):
references the symbols A through G.
refs_from_enclosing (default: False) -- If True, the symbols
referenced by enclosing menus and if's will be
included in the result."""
return self.all_referenced_syms if refs_from_enclosing else self.referenced_syms
@@ -2323,13 +2323,13 @@ class Symbol(Item):
self.rev_dep = "n"
# The prompt, default value and select conditions without any
# dependencies from menus or if's propagated to them
self.orig_prompts = []
self.orig_def_exprs = []
self.orig_selects = []
# Dependencies inherited from containing menus and if's
self.deps_from_containing = None
self.help = None
@@ -2343,7 +2343,7 @@ class Symbol(Item):
self.selected_syms = set()
# Like 'referenced_syms', but includes symbols from
# dependencies inherited from enclosing menus and if's
self.all_referenced_syms = set()
# This is set to True for "actual" choice symbols. See
@@ -2644,7 +2644,7 @@ class Menu(Item):
"Title : " + self.title,
"'depends on' dependencies : " + depends_on_str,
"'visible if' dependencies : " + visible_if_str,
- "Additional dependencies from enclosing menus and if's:",
+ "Additional dependencies from enclosing menus and ifs:",
additional_deps_str,
"Location: {0}:{1}".format(self.filename, self.linenr))
@@ -2664,10 +2664,10 @@ class Menu(Item):
self.dep_expr = None
# Dependency expression without dependencies from enclosing menus and
- # if's propagated
+ # ifs propagated
self.orig_deps = None
# Dependencies inherited from containing menus and if's
self.deps_from_containing = None
# The 'visible if' expression
@@ -2678,7 +2678,7 @@ class Menu(Item):
self.referenced_syms = set()
# Like 'referenced_syms', but includes symbols from
# dependencies inherited from enclosing menus and if's
self.all_referenced_syms = None
self.filename = None
@@ -2891,12 +2891,12 @@ class Choice(Item):
self.block = None
# The prompts and default values without any dependencies from
# enclosing menus or if's propagated
self.orig_prompts = []
self.orig_def_exprs = []
# Dependencies inherited from containing menus and if's
self.deps_from_containing = None
# We need to filter out symbols that appear within the choice block but
@@ -2910,7 +2910,7 @@ class Choice(Item):
self.referenced_syms = set()
# Like 'referenced_syms', but includes symbols from
# dependencies inherited from enclosing menus and if's
self.all_referenced_syms = set()
# See Choice.get_def_locations()
@@ -3031,7 +3031,7 @@ class Comment(Item):
return _sep_lines("Comment",
"Text: " + str(self.text),
"Dependencies: " + dep_str,
- "Additional dependencies from enclosing menus and if's:",
+ "Additional dependencies from enclosing menus and ifs:",
additional_deps_str,
"Location: {0}:{1}".format(self.filename, self.linenr))
@@ -3050,10 +3050,10 @@ class Comment(Item):
self.dep_expr = None
# Dependency expression without dependencies from enclosing menus and
- # if's propagated
+ # ifs propagated
self.orig_deps = None
# Dependencies inherited from containing menus and if's
self.deps_from_containing = None
# The set of symbols referenced by this comment (see
@@ -3061,7 +3061,7 @@ class Comment(Item):
self.referenced_syms = set()
# Like 'referenced_syms', but includes symbols from
# dependencies inherited from enclosing menus and if's
self.all_referenced_syms = None
self.filename = None
@@ -895,12 +895,12 @@ class Config(object):
parent -- The enclosing menu, choice or if, or None if we're at the top
level.
- deps -- Dependencies from enclosing menus, choices and if's.
+ deps -- Dependencies from enclosing menus, choices and ifs.
visible_if_deps (default: None) -- 'visible if' dependencies from
enclosing menus.
@@ -1309,7 +1309,7 @@ class Config(object):
self.end_line_tokens = tokens
break
- # Propagate dependencies from enclosing menus and if's.
+ # Propagate dependencies from enclosing menus and ifs.
# For menus and comments..
if isinstance(stmt, (Menu, Comment)):
@@ -1359,15 +1359,15 @@ class Config(object):
if isinstance(stmt, Symbol):
stmt.orig_selects.extend(new_selects)
- # Save dependencies from enclosing menus and if's
+ # Save dependencies from enclosing menus and ifs
stmt.deps_from_containing = deps
# The set of symbols referenced directly by the symbol/choice plus
@@ -1359,15 +1359,15 @@ class Config(object):
stmt.deps_from_containing = deps
# The set of symbols referenced directly by the symbol/choice plus
- # all symbols referenced by enclosing menus and if's.
+ # all symbols referenced by enclosing menus and ifs.
stmt.all_referenced_syms = \
stmt.referenced_syms | _get_expr_syms(deps)
@@ -1359,15 +1359,15 @@ class Config(object):
stmt.all_referenced_syms = \
stmt.referenced_syms | _get_expr_syms(deps)
- # Propagate dependencies from enclosing menus and if's
+ # Propagate dependencies from enclosing menus and ifs
stmt.def_exprs.extend([(val_expr, _make_and(cond_expr, deps))
for val_expr, cond_expr in new_def_exprs])
@@ -2182,7 +2182,7 @@ class Symbol(Item):
references the symbols A through G.
refs_from_enclosing (default: False) -- If True, the symbols
- referenced by enclosing menus and if's will be
+ referenced by enclosing menus and ifs will be
included in the result."""
return self.all_referenced_syms if refs_from_enclosing else self.referenced_syms
@@ -2323,13 +2323,13 @@ class Symbol(Item):
self.rev_dep = "n"
# The prompt, default value and select conditions without any
- # dependencies from menus or if's propagated to them
+ # dependencies from menus or ifs propagated to them
self.orig_prompts = []
self.orig_def_exprs = []
@@ -2323,13 +2323,13 @@ class Symbol(Item):
self.orig_def_exprs = []
self.orig_selects = []
- # Dependencies inherited from containing menus and if's
+ # Dependencies inherited from containing menus and ifs
self.deps_from_containing = None
self.help = None
@@ -2343,7 +2343,7 @@ class Symbol(Item):
self.selected_syms = set()
# Like 'referenced_syms', but includes symbols from
- # dependencies inherited from enclosing menus and if's
+ # dependencies inherited from enclosing menus and ifs
self.all_referenced_syms = set()
# This is set to True for "actual" choice symbols. See
@@ -2664,10 +2664,10 @@ class Menu(Item):
self.orig_deps = None
- # Dependencies inherited from containing menus and if's
+ # Dependencies inherited from containing menus and ifs
self.deps_from_containing = None
# The 'visible if' expression
@@ -2678,7 +2678,7 @@ class Menu(Item):
self.referenced_syms = set()
# Like 'referenced_syms', but includes symbols from
- # dependencies inherited from enclosing menus and if's
+ # dependencies inherited from enclosing menus and ifs
self.all_referenced_syms = None
self.filename = None
@@ -2891,12 +2891,12 @@ class Choice(Item):
self.block = None
# The prompts and default values without any dependencies from
- # enclosing menus or if's propagated
+ # enclosing menus or ifs propagated
self.orig_prompts = []
self.orig_def_exprs = []
@@ -2891,12 +2891,12 @@ class Choice(Item):
self.orig_prompts = []
self.orig_def_exprs = []
- # Dependencies inherited from containing menus and if's
+ # Dependencies inherited from containing menus and ifs
self.deps_from_containing = None
# We need to filter out symbols that appear within the choice block but
@@ -2910,7 +2910,7 @@ class Choice(Item):
self.referenced_syms = set()
# Like 'referenced_syms', but includes symbols from
- # dependencies inherited from enclosing menus and if's
+ # dependencies inherited from enclosing menus and ifs
self.all_referenced_syms = set()
# See Choice.get_def_locations()
@@ -3050,10 +3050,10 @@ class Comment(Item):
self.orig_deps = None
- # Dependencies inherited from containing menus and if's
+ # Dependencies inherited from containing menus and ifs
self.deps_from_containing = None
# The set of symbols referenced by this comment (see
@@ -3061,7 +3061,7 @@ class Comment(Item):
self.referenced_syms = set()
# Like 'referenced_syms', but includes symbols from
- # dependencies inherited from enclosing menus and if's
+ # dependencies inherited from enclosing menus and ifs
self.all_referenced_syms = None
self.filename = None